/*
 *  Aquamarine the KDE window decorator
 *
 *  Copyright (c) 2006 Dennis Kasprzyk <onestone@beryl-project.org>
 *  Copyright (c) 2006 Volker Krause <vkrause@kde.org>
 *
 *  Uses code of:
 *      Emerald window decorator (www.beryl-project.org)
 *      gtk-window-decorator (www.freedesktop.org/wiki/Software/Compiz)
 *      KWin window manager (www.kde.org)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 */

#ifndef AQUAMARINE_DEFAULT_H
#define AQUAMARINE_DEFAULT_H

#include <kdecoration_p.h>

#include <qpixmap.h>
#include <qwidget.h>

#include "utils.h"
#include "options.h"

class KDecoration;
class QPopupMenu;

namespace Aquamarine
{

    class DefaultDecoration:public QWidget, public KDecorationBridge
    {
      Q_OBJECT public:

      public:
            DefaultDecoration (bool active);
           ~DefaultDecoration ();

        // KDecorationBridge methods
        virtual bool isActive () const;
        virtual bool isCloseable () const;
        virtual bool isMaximizable () const;
        virtual MaximizeMode maximizeMode () const;
        virtual bool isMinimizable () const;
        virtual bool providesContextHelp () const;
        virtual int desktop () const;
        virtual bool isModal () const;
        virtual bool isShadeable () const;
        virtual bool isShade () const;
        virtual bool isSetShade () const;
        virtual bool keepAbove () const;
        virtual bool keepBelow () const;
        virtual bool isMovable () const;
        virtual bool isResizable () const;
        virtual NET::
            WindowType windowType (unsigned long supported_types) const;
        virtual QIconSet icon () const;
        virtual QString caption () const;
        virtual void processMousePressEvent (QMouseEvent *);
        virtual void showWindowMenu (const QRect &);
        virtual void showWindowMenu (QPoint);
        virtual void performWindowOperation (WindowOperation);
        virtual void setMask (const QRegion &, int);
        virtual bool isPreview () const;
        virtual QRect geometry () const;
        virtual QRect iconGeometry () const;
        virtual QRegion unobscuredRegion (const QRegion & r) const;
        virtual QWidget *workspaceWidget () const;
        virtual WId windowId () const;
        virtual void closeWindow ();
        virtual void maximize (MaximizeMode mode);
        virtual void minimize ();
        virtual void showContextHelp ();
        virtual void setDesktop (int desktop);
        virtual void titlebarDblClickOperation ();
        virtual void titlebarMouseWheelOperation (int delta);
        virtual void setShade (bool set);
        virtual void setKeepAbove (bool);
        virtual void setKeepBelow (bool);

        virtual int currentDesktop () const;
        virtual QWidget *initialParentWidget () const;
        virtual Qt::WFlags initialWFlags () const;
        virtual void helperShowHide (bool);
        virtual void grabXServer (bool grab);

        void reloadDecoration ();

      private:
        void createDecoration ();
        void resizeDecoration ( bool force = false );

      private slots:
        void grabChildWidgets ();
		void updateWindowProperties ();

      private:

        // window properties
        QRect m_geometry;
        bool m_active;
        QString m_name;
        QIconSet m_icons;

        // decoration stuff
        KDecoration *m_deco;
        QPixmap m_qpixmap;

    };

}

#endif
